@@ -14,6 +14,13 @@ class Daemon : public QObject
     Q_OBJECT
     Q_CLASSINFO("AppLock Daemon", "com.sierrasoftworks.AppLock")
 
+private:
+    PhoneControl *phoneControl;
+    Settings *settings;
+
+    DBusMonitor *sessionMonitor;
+    LaunchMonitor *launchMonitor;
+
 public:
     explicit Daemon();
     virtual ~Daemon();
@@ -24,13 +31,18 @@ private slots:
     void OnSystemBusMethod(QString interface, QString method);
 
 public slots:
-    void PrintMonitorList();
-    void PrintStatus();
     QString GetStatus();
     bool AddSearch(QString name, QString bus, QString search);
     bool AddApp(QString name, QString path);
+    bool AddCMD(QString name, QString cmdline);
     bool RemoveSearch(QString name);
     bool RemoveApp(QString name);
+    bool RemoveCMD(QString name);
+    bool IsLockedApp(QString name);
+    bool IsLockedDBus(QString name);
+    bool IsLockedCMD(QString name);
+    void Refresh();
+    void Exit();
 
 signals:
     void LockedAppLaunched(QString app);
